Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConsumerConfig ¶ added in v1.1.0
type Kafka ¶
type Kafka struct {
// contains filtered or unexported fields
}
Kafka implements the "ICheckable" interface.
func NewKafka ¶
func NewKafka(cfg KafkaConfig) (*Kafka, error)
NewKafka builds a go-kafka check initialized with the provided configuration.
type KafkaConfig ¶
type KafkaConfig struct {
BootstrapServers string // coma separated list of kafka brokers
Topic string // topic to connect to (make sure it exists)
PollTimeout time.Duration // time spent fetching the data from the topic
CheckTimeout time.Duration // maximum time to wait for the check to complete
SkipConsumerTimeouts int // maximum number of check timeouts to skip at the beginning when consuming messages
ConsumerConfig ConsumerConfig // consumer configuration (see https://github.com/confluentinc/librdkafka/blob/master/CONFIGURATION.md)
ProducerConfig ProducerConfig // producer configuration (see https://github.com/confluentinc/librdkafka/blob/master/CONFIGURATION.md)
}
KafkaConfig is used for configuring the go-kafka check.
type ProducerConfig ¶ added in v1.1.0
Click to show internal directories.
Click to hide internal directories.